@@ -12,7 +12,7 @@
  * for the specific language governing rights and limitations under the
  * License.
  * 
- * Copyright (C) 2008-2011 Laurent Gautier
+ * Copyright (C) 2008-2012 Laurent Gautier
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -31,7 +31,7 @@
 #include <Python.h>
 #include <Rdefines.h>
 #include <Rinternals.h>
-#include "rpy_rinterface.h"
+#include "_rinterface.h"
 
 #include "embeddedr.h"
 #include "sexp.h"
@@ -198,18 +198,18 @@ VectorSexp_item(PySexpObject* object, Py_ssize_t i)
     case VECSXP:
     case EXPRSXP:
       sexp_item = VECTOR_ELT(*sexp, i_R);
-      res = (PyObject *)newPySexpObject(sexp_item, 1);
+      res = (PyObject *)newPySexpObject(sexp_item);
       break;
     case LISTSXP:
       tmp = nthcdr(*sexp, i_R);
       sexp_item = allocVector(LISTSXP, 1);
       SETCAR(sexp_item, CAR(tmp));
       SET_TAG(sexp_item, TAG(tmp));
-      res = (PyObject *)newPySexpObject(sexp_item, 1);
+      res = (PyObject *)newPySexpObject(sexp_item);
       break;      
     case LANGSXP:
       sexp_item = CAR(nthcdr(*sexp, i_R));
-      res = (PyObject *)newPySexpObject(sexp_item, 1);
+      res = (PyObject *)newPySexpObject(sexp_item);
       break;
     default:
       PyErr_Format(PyExc_ValueError, "Cannot handle type %d", 
@@ -359,7 +359,7 @@ VectorSexp_slice(PySexpObject* object, Py_ssize_t ilow, Py_ssize_t ihigh)
   embeddedR_freelock();
   if (res_sexp == NULL) {    return NULL;
   }
-  return (PyObject*)newPySexpObject(res_sexp, 1);
+  return (PyObject*)newPySexpObject(res_sexp);
 }
 
 
@@ -475,7 +475,6 @@ static int
 VectorSexp_ass_slice(PySexpObject* object, Py_ssize_t ilow, Py_ssize_t ihigh, PyObject *val)
 {
   R_len_t len_R;
-  int self_typeof;
 
   if (rpy_has_status(RPY_R_BUSY)) {
     PyErr_Format(PyExc_RuntimeError, "Concurrent access to R is not allowed.");
@@ -538,8 +537,6 @@ VectorSexp_ass_slice(PySexpObject* object, Py_ssize_t ilow, Py_ssize_t ihigh, Py
 
     R_len_t slice_len = ihigh-ilow;
     R_len_t slice_i;
-    const char *vs;
-    SEXP tmp, sexp_item; /* tmp and sexp_item needed for case LANGSXP */
 
     SEXP sexp_val = RPY_SEXP((PySexpObject *)val);
     if (! sexp_val) {
@@ -902,16 +899,14 @@ VectorSexp_init(PyObject *self, PyObject *args, PyObject *kwds)
 
   PyObject *object;
   int sexptype = -1;
-  PyObject *copy = Py_False;
-  static char *kwlist[] = {"sexpvector", "sexptype", "copy", NULL};
+  static char *kwlist[] = {"sexpvector", "sexptype", NULL};
 
 
   /* FIXME: handle the copy argument */
-  if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|iO!", 
+  if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|i", 
                                     kwlist,
                                     &object,
-                                    &sexptype,
-                                    &PyBool_Type, &copy)) {
+                                    &sexptype)) {
     return -1;
   }
 
@@ -925,10 +920,10 @@ VectorSexp_init(PyObject *self, PyObject *args, PyObject *kwds)
                           (PyObject*)&VectorSexp_Type)) {
     /* call parent's constructor */
       if (Sexp_init(self, args, NULL) == -1) {
-      /* PyErr_Format(PyExc_RuntimeError, "Error initializing instance."); */
-      embeddedR_freelock();
-      return -1;
-    }
+	/* PyErr_Format(PyExc_RuntimeError, "Error initializing instance."); */
+	embeddedR_freelock();
+	return -1;
+      }
   } else if (PySequence_Check(object)) {
     if ((sexptype < 0) || (sexptype > RPY_MAX_VALIDSEXTYPE) || 
         (! validSexpType[sexptype])) {
@@ -939,16 +934,23 @@ VectorSexp_init(PyObject *self, PyObject *args, PyObject *kwds)
     /* FIXME: implemement automagic type ?
      *(RPy has something)... or leave it to extensions ? 
      */
-
     SEXP sexp = newSEXP(object, sexptype);
+    PROTECT(sexp); /* sexp is not preserved*/
     if (sexp == NULL) {
       /* newSEXP returning NULL will also have raised an exception
        * (not-so-clear design :/ )
        */
+      UNPROTECT(1);
       embeddedR_freelock();
       return -1;
     }
-    RPY_SEXP((PySexpObject *)self) = sexp;
+    if (Rpy_ReplaceSexp((PySexpObject *)self, sexp) == -1) {
+      embeddedR_freelock();
+      UNPROTECT(1);
+      return -1;
+    }
+    UNPROTECT(1);
+
     #ifdef RPY_DEBUG_OBJECTINIT
     printf("  SEXP vector is %p.\n", RPY_SEXP((PySexpObject *)self));
     #endif
@@ -1018,6 +1020,8 @@ VectorSexp_init_private(PyObject *self, PyObject *args, PyObject *kwds,
       return -1;
     }
   } else {
+    /* The parameter is not already a PySexpObject. Create
+     the necessary PySexpObjects. */
     int is_sequence = PySequence_Check(object);
     if ( !is_sequence ) {
       Py_ssize_t length = PyObject_Length(object);
@@ -1045,20 +1049,22 @@ VectorSexp_init_private(PyObject *self, PyObject *args, PyObject *kwds,
 #endif 
       
       if (seq_to_R(object, &sexp) == -1) {
-	/* RPy_SeqTo*SXP already raises an exception in case of problem
+	/* RPy_SeqTo*SXP returns already raises an exception in case of problem
 	 */
 	embeddedR_freelock();
 	return -1;
       }
       
-      R_PreserveObject(sexp);
+      //R_PreserveObject(sexp);
 #ifdef RPY_DEBUG_PRESERVE
       preserved_robjects += 1;
       printf("  PRESERVE -- R_PreserveObject -- %p -- %i\n", 
 	     sexp, preserved_robjects);
 #endif  
-      
-      RPY_SEXP((PySexpObject *)self) = sexp;
+      if (Rpy_ReplaceSexp((PySexpObject *)self, sexp) == -1) {
+	embeddedR_freelock();
+	return -1;
+      }
 #ifdef RPY_DEBUG_OBJECTINIT
       printf("  SEXP vector is %p.\n", RPY_SEXP((PySexpObject *)self));
 #endif
@@ -1292,6 +1298,9 @@ IntVectorSexp_AsSexp(PyObject *pyfloat) {
   PyObject *seq_tmp = PyTuple_New(1);
   PyTuple_SetItem(seq_tmp, 0, pyfloat);
   status = RPy_SeqToINTSXP(seq_tmp, &sexp);
+  if (status == -1) {
+    return NULL;
+  }
   Py_DECREF(seq_tmp);
   return sexp;
 }
@@ -1308,7 +1317,6 @@ IntVectorSexp_init(PyObject *self, PyObject *args, PyObject *kwds)
 				(RPy_seqobjtosexpproc)RPy_SeqToINTSXP,
 				(RPy_iterobjtosexpproc)RPy_IterToINTSXP,
 				INTSXP);
-
 #ifdef RPY_VERBOSE
   printf("done (IntVectorSexp_init).\n");
 #endif 
@@ -1499,6 +1507,9 @@ FloatVectorSexp_AsSexp(PyObject *pyfloat) {
   PyObject *seq_tmp = PyTuple_New(1);
   PyTuple_SetItem(seq_tmp, 0, pyfloat);
   status = RPy_SeqToREALSXP(seq_tmp, &sexp);
+  if (status == -1) {
+    return NULL;
+  }
   Py_DECREF(seq_tmp);
   return sexp;
 }
@@ -1658,7 +1669,7 @@ RPy_SeqToSTRSXP(PyObject *object, SEXP *sexpp)
 		     "Error raised by codec for element %zd.",
 		     ii);
 	Py_XDECREF(seq_object);
-	return -1;
+	return -1;	
       }
       const char *string = PyBytes_AsString(item_tmp);
       str_R = mkCharCE(string, CE_UTF8);
@@ -1672,8 +1683,8 @@ RPy_SeqToSTRSXP(PyObject *object, SEXP *sexpp)
 	PyErr_Format(PyExc_ValueError,
 		     "Error raised when calling str() for element %zd.",
 		     ii);
-	Py_XDECREF(seq_object);	
-	return -1;
+	Py_XDECREF(seq_object);
+	return -1;	
       }
 #if (PY_VERSION_HEX < 0x03010000)
       str_R = mkChar(PyString_AS_STRING(item_tmp));
@@ -1685,7 +1696,7 @@ RPy_SeqToSTRSXP(PyObject *object, SEXP *sexpp)
 		     "Error raised by codec for str(element %zd).",
 		     ii);
 	Py_XDECREF(seq_object);
-	return -1;
+	return -1;	
       }
       const char *string = PyBytes_AsString(item_tmp2);
       str_R = mkCharCE(string, CE_UTF8);
@@ -1710,6 +1721,9 @@ StrVectorSexp_AsSexp(PyObject *pyfloat) {
   PyObject *seq_tmp = PyTuple_New(1);
   PyTuple_SetItem(seq_tmp, 0, pyfloat);
   status = RPy_SeqToSTRSXP(seq_tmp, &sexp);
+  if (status == -1) {
+    return NULL;
+  }
   Py_DECREF(seq_tmp);
   return sexp;
 }
@@ -1874,6 +1888,9 @@ BoolVectorSexp_AsSexp(PyObject *pyfloat) {
   PyObject *seq_tmp = PyTuple_New(1);
   PyTuple_SetItem(seq_tmp, 0, pyfloat);
   status = RPy_SeqToLGLSXP(seq_tmp, &sexp);
+  if (status == -1) {
+    return NULL;
+  }
   Py_DECREF(seq_tmp);
   return sexp;
 }
@@ -2176,6 +2193,9 @@ ComplexVectorSexp_AsSexp(PyObject *pyfloat) {
   PyObject *seq_tmp = PyTuple_New(1);
   PyTuple_SetItem(seq_tmp, 0, pyfloat);
   status = RPy_SeqToCPLXSXP(seq_tmp, &sexp);
+  if (status == -1) {
+    return NULL;
+  }
   Py_DECREF(seq_tmp);
   return sexp;
 }
