@@ -35,10 +35,6 @@ def suite():
         ])
     return alltests
 
-def main():
-    r = unittest.TestResult()
-    suite().run(r)
-    return r
 
 if __name__ == '__main__':    
     tr = unittest.TextTestRunner(verbosity = 2)
