@@ -1,14 +1,25 @@
 import unittest
 import rpy2.rinterface as rinterface
-import rpy2.rinterface.rpy_device as rdevice
+import rpy2.rinterface._rpy_device as rdevice
 import sys, os, subprocess, time, tempfile, signal
 import tempfile
 
 rinterface.initr()
 
+class AbstractDevice(rdevice.GraphicalDevice):
+    def __init__(self):
+        super(AbstractDevice, self).__init__()
+    def activate(self):
+        self._activated = True
+    def deactivate(self):
+        self._activated = False
+    def close(self):
+        pass
+
+
 class AbstractDeviceTestCase(unittest.TestCase):
     def setUp(self):
-        self.gd = rdevice.GraphicalDevice()
+        self.gd = AbstractDevice()
 
     def tearDown(self):
         self.gd = None
@@ -34,7 +45,7 @@ class AbstractDeviceTestCase(unittest.TestCase):
         self._testGetSetBooleanAttr("hasTextUTF8")
 
     def testWantSymbolUTF8(self):
-        self._testGetSetBooleanAttr("wantSymbolUTF8")
+       self._testGetSetBooleanAttr("wantSymbolUTF8")
     
     def testLeft(self):
         self._testGetSetDoubleAttr("left")
@@ -60,50 +71,51 @@ class AbstractDeviceTestCase(unittest.TestCase):
     def testDisplayListOn(self):
         self._testGetSetBooleanAttr("displayListOn")
   
-   
+
+class CodeDevice(rdevice.GraphicalDevice):
+
+    def __init__(self, filehandle):
+        super(CodeDevice, self).__init__()
+        self._activated = None
+        self._open = True
+        self._pagecount = 0
+        self._file = filehandle
+
+    def activate(self):
+        self._activated = True
+
+    def deactivate(self):
+        self._activated = False
+
+    def close(self):
+        self._activated = None
+        self._open = False
+        self._file.close()
+
+    def size(self, lrbt):
+        return (1,2,3,4)
+
+    def newpage(self):
+        self._file.write('#--- new page\n')
+        self._pagecount = self._pagecount + 1
+
+    def line(self, x1, y1, x2, y2):
+        self._file.write('line(%f, %f, %f, %f)' %(x1, y1, x2, y2))
+
+    def polyline(self, x, y):
+        for xx, yy in zip(x, y):
+            self._file.write('polyline(%f, %f)' %(xx, yy))
+
+    def clip(self, x1, y1, x2, y2):
+        self._file.write('clip(%f, %f, %f, %f)' %(x1, y1, x2, y2))
+
         
 class ConcreteDeviceTestCase(unittest.TestCase):
     
-    class CodeDevice(rdevice.GraphicalDevice):
-        
-        def __init__(self, filehandle):
-            super(ConcreteDeviceTestCase.CodeDevice, self).__init__()
-            self._activated = None
-            self._open = True
-            self._pagecount = 0
-            self._file = filehandle
-            
-        def activate(self):
-            self._activated = True
-
-        def deactivate(self):
-            self._activated = False
-
-        def close(self):
-            self._activated = None
-            self._open = False
-            self._file.close()
-            
-        def size(self, lrbt):
-            return (1,2,3,4)
-
-        def newpage(self):
-            self._file.write('#--- new page\n')
-            self._pagecount = self._pagecount + 1
-
-        def line(self, x1, y1, x2, y2):
-            self._file.write('line(%f, %f, %f, %f)' %(x1, y1, x2, y2))
-
-        def polyline(self, x, y):
-            self._file.write('polyline(%f, %f)' %(x, y))
-            
-        def clip(self, x1, y1, x2, y2):
-            self._file.write('clip(%f, %f, %f, %f)' %(x1, y1, x2, y2))
-
     def setUp(self):
         #f = tempfile.NamedTemporaryFile()
         f = file('/tmp/foo', mode='w')
-        self.gd = ConcreteDeviceTestCase.CodeDevice(f)
+        self.gd = CodeDevice(f)
 
     def tearDown(self):
         self.gd.close()
