@@ -102,7 +102,20 @@ class SexpTestCase(unittest.TestCase):
         d = dict(rinterface._rinterface.protected_rids())
         self.assertEqual(None, d.get(sexp2_rid))
 
+    def testSexp_rclass_get(self):
+        sexp = rinterface.baseenv.get("letters")
+        self.assertEqual(len(sexp.rclass), 1)
+        self.assertEqual(sexp.rclass[0], "character")
+        sexp = rinterface.baseenv.get("matrix")(0)
+        self.assertEqual(len(sexp.rclass), 1)
+        self.assertEqual(sexp.rclass[0], "matrix")
 
+    def testSexp_rclass_set(self):
+        sexp = rinterface.IntSexpVector([1,2,3])
+        sexp.rclass = rinterface.StrSexpVector(['foo'])
+        self.assertEqual(len(sexp.rclass), 1)
+        self.assertEqual(sexp.rclass[0], "foo")
+        
     def testSexp_sexp_wrongtypeof(self):
         sexp = rinterface.IntSexpVector([1,2,3])
         cobj = sexp.__sexp__
