@@ -638,6 +638,12 @@ class ScaleShapeManual(ScaleShape):
 scale_shape_manual = ScaleShapeManual.new
 
 
+
+guides = ggplot2.guides
+guide_colorbar = ggplot2.guide_colorbar
+guide_colourbar = ggplot2.guide_colourbar
+guide_legend = ggplot2.guide_legend
+
 class Options(robjects.Vector):
    def __init__(self, obj):
       self.__sexp__ = obj.__sexp__
@@ -663,7 +669,16 @@ class ElementText(Element):
        return res
 element_text = ElementText.new
 
-
+class ElementRect(Element):
+    _constructor = ggplot2.element_rect
+    @classmethod
+    def new(cls, fill = NULL, colour = NULL, size = NULL,
+            linetype = NULL, color = NULL):
+       res = cls(cls._constructor(fill = fill, colour = colour,
+                                  size = size, linetype = linetype,
+                                  color = color))
+       return res
+element_rect = ElementRect.new
 
 class Theme(Options):
    pass
@@ -697,6 +712,16 @@ class ThemeGrey(Theme):
 
 theme_grey = ThemeGrey.new
 
+class ThemeClassic(Theme):
+    _constructor = ggplot2.theme_classic
+    @classmethod
+    def new(cls, base_size = 12, base_family = ""):
+       res = cls(cls._constructor(base_size = base_size,
+                                  base_family = base_family))
+       return res
+
+theme_classic = ThemeClassic.new
+
 class ThemeRect(Theme):
     _constructor = ggplot2.theme_rect
     @classmethod
