@@ -16,6 +16,12 @@ import testLanguage
 # wrap this nicely so a warning is issued if no numpy present
 import testNumpyConversions
 
+# wrap this nicely so a warning is issued if no numpy present
+import testPandasConversions
+
+# mapped R libraries
+import rpy2.robjects.lib.tests
+
 def suite():
     suite_RObject = testRObject.suite()
     suite_Vector = testVector.suite()
@@ -26,10 +32,13 @@ def suite():
     suite_Formula = testFormula.suite()
     suite_Robjects = testRobjects.suite()
     suite_NumpyConversions = testNumpyConversions.suite()
+    suite_PandasConversions = testPandasConversions.suite()
     suite_Methods = testMethods.suite()
     suite_Packages = testPackages.suite()
     suite_Help = testHelp.suite()
     suite_Language = testLanguage.suite()
+    # lib
+    suite_lib = rpy2.robjects.lib.tests.suite()
     alltests = unittest.TestSuite([suite_RObject,
                                    suite_Vector,                   
                                    suite_Array,
@@ -40,9 +49,11 @@ def suite():
                                    suite_Robjects,
                                    suite_Methods,
                                    suite_NumpyConversions,
+                                   suite_PandasConversions,
                                    suite_Packages,
                                    suite_Help,
-                                   suite_Language
+                                   suite_Language,
+                                   suite_lib
                                    ])
     return alltests
 
