@@ -2,6 +2,8 @@ import unittest
 import rpy2.robjects as robjects
 ri = robjects.rinterface
 import array, time, sys
+import time
+import datetime
 import rpy2.rlike.container as rlc
 from collections import OrderedDict
 
@@ -165,7 +167,7 @@ class VectorTestCase(unittest.TestCase):
                                                ('b', robjects.Formula('y ~ x')),
                                                )))
         s = repr(vec).split('\n')
-        self.assertEqual('[IntVector, Formula]', s[1])
+        self.assertEqual('[IntVector, Formula]', s[1].strip())
 
     def testIteritems(self):
         vec = robjects.IntVector(range(3))
@@ -233,7 +235,8 @@ class DateTimeVectorTestCase(unittest.TestCase):
         x = [time.struct_time(_dateval_tuple), 
              time.struct_time(_dateval_tuple)]
         x.append('foo')
-        self.assertRaises(ValueError, robjects.POSIXct, x)
+        # string 'foo' does not have attribute 'tm_zone'  
+        self.assertRaises(AttributeError, robjects.POSIXct, x)
 
     def testPOSIXct_fromPythonTime(self):
         x = [time.struct_time(_dateval_tuple), 
@@ -241,6 +244,17 @@ class DateTimeVectorTestCase(unittest.TestCase):
         res = robjects.POSIXct(x)
         self.assertEqual(2, len(x))
 
+    def testPOSIXct_fromPythonDatetime(self):
+        x = [datetime.datetime(*_dateval_tuple[:-2]), 
+             datetime.datetime(*_dateval_tuple[:-2])]
+        res = robjects.POSIXct(x)
+        self.assertEqual(2, len(x))
+
+    def testPOSIXct_fromSexp(self):
+        sexp = robjects.r('ISOdate(2013, 12, 11)')
+        res = robjects.POSIXct(sexp)
+        self.assertEqual(1, len(res))
+
 class ExtractDelegatorTestCase(unittest.TestCase):
 
     def setUp(self):
