@@ -7,9 +7,13 @@ import rpy2.rlike.container as rlc
 
 import sys, copy, os, itertools, math
 import time
-from time import struct_time, mktime
+from datetime import datetime
+from time import struct_time, mktime, tzname
+from operator import attrgetter
 
-from rpy2.rinterface import Sexp, SexpVector, ListSexpVector, StrSexpVector, IntSexpVector, BoolSexpVector, ComplexSexpVector, FloatSexpVector, R_NilValue, NA_Real, NA_Integer, NA_Character, NA_Logical, NULL
+from rpy2.rinterface import Sexp, SexpVector, ListSexpVector, StrSexpVector, \
+    IntSexpVector, BoolSexpVector, ComplexSexpVector, FloatSexpVector, \
+    R_NilValue, NA_Real, NA_Integer, NA_Character, NA_Logical, NULL, MissingArg
 
 globalenv_ri = rinterface.globalenv
 baseenv_ri = rinterface.baseenv
@@ -43,13 +47,18 @@ class ExtractDelegator(object):
            - an index is itself a vector of elements to select
         """
 
-        args = [conversion.py2ro(x) for x in args]
+        conv_args = list(None for x in xrange(len(args)))
+        for i, x in enumerate(args):
+            if x is MissingArg:
+                conv_args[i] = x
+            else:
+                conv_args[i] = conversion.py2ro(x)
         kwargs = copy.copy(kwargs)
         for k, v in kwargs.itervalues():
             kwargs[k] = conversion.py2ro(v)
         fun = self._extractfunction
-        args.insert(0, self._parent)
-        res = fun(*args, **kwargs)
+        conv_args.insert(0, self._parent)
+        res = fun(*conv_args, **kwargs)
         res = conversion.py2ro(res)
         return res
 
@@ -57,6 +66,8 @@ class ExtractDelegator(object):
         fun = self._extractfunction
         args = rlc.TaggedList(item)
         for i, (k, v) in enumerate(args.iteritems()):
+            if v is MissingArg:
+                continue
             args[i] = conversion.py2ro(v)
         args.insert(0, self._parent)
         res = fun.rcall(args.items(),
@@ -75,6 +86,8 @@ class ExtractDelegator(object):
         if type(item) is tuple:
             args = list([None, ] * (len(item)+2))
             for i, v in enumerate(item):
+                if v is MissingArg:
+                    continue
                 args[i+1] = conversion.py2ro(v)
             args[-1] = conversion.py2ro(value)
             args[0] = self._parent
@@ -218,6 +231,7 @@ class Vector(RObjectMixin, SexpVector):
 
     def __getitem__(self, i):
         res = super(Vector, self).__getitem__(i)
+        
         if isinstance(res, Sexp):
             res = conversion.ri2py(res)
         return res
@@ -271,6 +285,7 @@ class Vector(RObjectMixin, SexpVector):
 
     def __repr_content__(self):
         def p_str(x, max_width = 8):
+            max_width = int(max_width)
             if x is NA_Real or x is NA_Integer or x is NA_Character or x is NA_Logical:
                 res = repr(x)
             elif isinstance(x, long) or isinstance(x, int):
@@ -281,8 +296,7 @@ class Vector(RObjectMixin, SexpVector):
                 if isinstance(x, str):
                     x = x.__repr__()
                 else:
-                    tmp = ['', None, None, '']
-                    x = type(x).__name__                    
+                    x = type(x).__name__    
                 if len(x) < max_width:
                     res = x
                 else:
@@ -292,12 +306,12 @@ class Vector(RObjectMixin, SexpVector):
         l = len(self)
         if l < 7:
             s = '[' + \
-                ', '.join((p_str(x, max_width = math.floor(52 / l)) for x in self[ : 8])) +\
+                ', '.join((p_str(elt, max_width = math.floor(52 / l)) for elt in self[ : 8])) +\
                 ']'
         else:
             s = '[' + \
-                ', '.join((p_str(x) for x in self[ : 3])) + ', ..., ' + \
-                ', '.join((p_str(x) for x in self[-3 : ])) + \
+                ', '.join((p_str(elt) for elt in self[ : 3])) + ', ..., ' + \
+                ', '.join((p_str(elt) for elt in self[-3 : ])) + \
                 ']'
         return s
 
@@ -608,26 +622,83 @@ class POSIXct(POSIXt, FloatVector):
     sequence interface) of time.struct_time objects.
     """
 
+    _as_posixct = baseenv_ri['as.POSIXct']
+    _ISOdatetime = baseenv_ri['ISOdatetime']
+
     def __init__(self, seq):
-        """ 
+        """ Create a POSIXct from either an R vector or a sequence
+        of Python dates.
         """
 
         if isinstance(seq, Sexp):
-            super(self, FloatSexpVector)(seq)
+            super(FloatVector, self).__init__(seq)
+        elif isinstance(seq[0], struct_time):
+            sexp = POSIXct.sexp_from_struct_time(seq)
+            self.__sexp__ = sexp.__sexp__            
+        elif isinstance(seq[0], datetime):
+            sexp = POSIXct.sexp_from_datetime(seq)
+            self.__sexp__ = sexp.__sexp__                        
         else:
-            for elt in seq:
-                if not isinstance(elt, struct_time):
-                    raise ValueError('All elements must inherit from time.struct_time')
-            as_posixct = baseenv_ri['as.POSIXct']
-            origin = StrSexpVector([time.strftime("%Y-%m-%d", 
-                                                  time.gmtime(0)),])
-            rvec = FloatSexpVector([mktime(x) for x in seq]) 
-            sexp = as_posixct(rvec, origin = origin)
-            self.__sexp__ = sexp.__sexp__
-        
-        
+            raise ValueError('All elements must inherit from time.struct_time or datetime.datetime.')
+
+    @staticmethod
+    def _sexp_from_seq(seq, tz_info_getter, isodatetime_columns):
+        """ return a POSIXct vector from a sequence of time.struct_time 
+        elements. """
+        tz_count = 0
+        tz_info = None
+        for elt in seq:
+            tmp = tz_info_getter(elt)
+            if tz_info is None:
+                tz_info = tmp
+                tz_count = 1
+            elif tz_info == tmp:
+                tz_count += 1
+            else:
+                # different time zones
+                #FIXME: create a list of time zones with tz_count times
+                # tz_info, add the current tz_info and append further.
+                raise ValueError("Sequences of dates with different time zones not yet allowed.")
+
+        if tz_info is None:
+            tz_info = tzname[0]
+        # We could use R's as.POSIXct instead of ISOdatetime
+        # since as.POSIXct is used by it anyway, but the overall
+        # interface for dates and conversion between formats
+        # is not exactly straightforward. Someone with more
+        # time should look into this.
+
+        d = isodatetime_columns(seq)
+        sexp = POSIXct._ISOdatetime(*d, tz = StrSexpVector((tz_info, )))
+        return sexp
 
 
+    @staticmethod
+    def sexp_from_struct_time(seq):
+        def f(seq):
+            return [IntVector([x.tm_year for x in seq]),
+                    IntVector([x.tm_mon for x in seq]),
+                    IntVector([x.tm_mday for x in seq]),
+                    IntVector([x.tm_hour for x in seq]),
+                    IntVector([x.tm_min for x in seq]),
+                    IntVector([x.tm_sec for x in seq])]
+        return POSIXct._sexp_from_seq(seq, lambda elt: time.tzname[0], f)
+    
+    @staticmethod
+    def sexp_from_datetime(seq):
+        """ return a POSIXct vector from a sequence of
+        datetime.datetime elements. """
+        def f(seq):
+            return [IntVector([x.year for x in seq]),
+                    IntVector([x.month for x in seq]),
+                    IntVector([x.day for x in seq]),
+                    IntVector([x.hour for x in seq]),
+                    IntVector([x.minute for x in seq]),
+                    IntVector([x.second for x in seq])]
+        
+        return POSIXct._sexp_from_seq(seq, attrgetter('tzinfo'), f)
+       
+        
 class Array(Vector):
     """ An R array """
     _dimnames_get = baseenv_ri['dimnames']
@@ -713,10 +784,11 @@ class Matrix(Array):
                 raise ValueError('Invalid length.')
             if self.dimnames is NULL:
                 dn = ListVector.from_length(2)
+                dn[0] = rn
                 self.do_slot_assign('dimnames', dn)
             else:
                 dn = self.dimnames
-            dn[0] = rn
+                dn[0] = rn
         else:
             raise ValueError('The rownames attribute can only be an R string vector.')
     rownames = property(__rownames_get, __rownames_set, None, "Row names")
@@ -736,10 +808,11 @@ class Matrix(Array):
                 raise ValueError('Invalid length.')
             if self.dimnames is NULL:
                 dn = ListVector.from_length(2)
+                dn[1] = cn
                 self.do_slot_assign('dimnames', dn)
             else:
                 dn = self.dimnames
-            dn[1] = cn
+                dn[1] = cn
         else:
             raise ValueError('The colnames attribute can only be an R string vector.')
     colnames = property(__colnames_get, __colnames_set, None, "Column names")
@@ -789,35 +862,46 @@ class DataFrame(ListVector):
     _write_table = utils_ri['write.table']
     _cbind     = rinterface.baseenv['cbind.data.frame']
     _rbind     = rinterface.baseenv['rbind.data.frame']
+    _is_list   = rinterface.baseenv['is.list']
     
-    def __init__(self, tlist):
+    def __init__(self, obj):
         """ Create a new data frame.
 
-        :param tlist: rpy2.rlike.container.TaggedList or rpy2.rinterface.SexpVector (and of class 'data.frame' for R)
+        :param obj: object inheriting from rpy2.rinterface.SexpVector,
+                    or inheriting from TaggedList
+                    or a mapping name -> value
         """
-        if isinstance(tlist, rinterface.SexpVector):
-            if tlist.typeof != rinterface.VECSXP:
-                raise ValueError("tlist should of typeof VECSXP")
-            if not globalenv_ri.get('inherits')(tlist, self._dataframe_name)[0]:
-                raise ValueError('tlist should of R class "data.frame"')
-            super(DataFrame, self).__init__(tlist)
-        elif isinstance(tlist, rlc.TaggedList):
-            kv = [(k, conversion.py2ri(v)) for k,v in tlist.iteritems()]
+        if isinstance(obj, rinterface.SexpVector):
+            if obj.typeof != rinterface.VECSXP:
+                raise ValueError("obj should of typeof VECSXP"+\
+                                     " (and we get %s)" % rinterface.str_typeint(obj.typeof))
+            if self._is_list(obj)[0] or \
+                    globalenv_ri.get('inherits')(obj, self._dataframe_name)[0]:
+                #FIXME: is it really a good idea to pass R lists
+                # to the constructor ?
+                super(DataFrame, self).__init__(obj)
+            else:
+                raise ValueError(
+            "When passing R objects to build a DataFrame," +\
+                " the R object must be a list or inherit from" +\
+                " the R class 'data.frame'")
+        elif isinstance(obj, rlc.TaggedList):
+            kv = [(k, conversion.py2ri(v)) for k,v in obj.items()]
             kv = tuple(kv)
             df = baseenv_ri.get("data.frame").rcall(kv, globalenv_ri)
             super(DataFrame, self).__init__(df)
-        elif hasattr(tlist, "__iter__"):
-            if not callable(tlist.__iter__):
-                raise ValueError("tlist should have a /method/ __iter__ (not an attribute)")
-            kv = [(str(k), conversion.py2ri(tlist[k])) for k in tlist]
+        else:
+            try:
+                kv = [(str(k), conversion.py2ri(obj[k])) for k in obj]
+            except TypeError:
+                raise ValueError("obj can be either "+
+                                 "an instance of an iter-able class" +
+                                 "(such a Python dict, rpy2.rlike.container OrdDict" +
+                                 " or an instance of rpy2.rinterface.SexpVector" +
+                                 " of type VECSXP")
+            
             df = baseenv_ri.get("data.frame").rcall(tuple(kv), globalenv_ri)
             super(DataFrame, self).__init__(df)
-        else:
-            raise ValueError("tlist can be either "+
-                             "an instance of an iter-able class" +
-                             "(such a Python dict, rpy2.rlike.container OrdDict" +
-                             " or an instance of rpy2.rinterface.SexpVector" +
-                             " of type VECSXP")
     
     def _get_nrow(self):
         """ Number of rows. 
@@ -852,6 +936,14 @@ class DataFrame(ListVector):
         
     colnames = property(_get_colnames, _set_colnames, None)
 
+    def __getitem__(self, i):
+        # Make sure this is not a List returned
+        # FIXME: should this be optimzed ?
+        tmp = super(DataFrame, self).__getitem__(i)
+        if tmp.typeof == rinterface.VECSXP:
+            return DataFrame(tmp)
+        else:
+            return conversion.ri2py(tmp)
 
     def cbind(self, *args, **kwargs):
         """ bind objects as supplementary columns """
